# import libraries
from datetime import datetime
import lxml
from lxml import html
import requests
import numpy as np
import pandas as pd

headers = {
    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3',
    'Accept-Encoding': 'gzip, deflate, br',
    'Accept-Language': 'en-US,en;q=0.9',
    'Cache-Control': 'max-age=0',
    'Pragma': 'no-cache',
    'Referrer': 'https://google.com',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.120 Safari/537.36'
}
url = "http://127.0.0.1:5000/api"
#url = "https://finance.99onez.com/api"

def getIndustry(name,type,startDate=None,endDate=None):

    if not startDate:
        startDate = ''
    if not endDate:
        endDate = ''
    page = requests.get(url+'/industry2?name='+name+'&type='+type+'&startDate='+str(startDate)+'&endDate='+str(endDate), headers)
    return page.json()

def getConcept(name,type,startDate=None,endDate=None):
    if not startDate:
        startDate = ''
    if not endDate:
        endDate = ''
    #print(url)
    page = requests.get(url+'/concept?name='+name+'&type='+type+'&startDate='+str(startDate)+'&endDate='+str(endDate), headers)
    return page.json()

def getConceptArr(nameArr,type,startDate=None,endDate=None):
    if not startDate:
        startDate = ''
    if not endDate:
        endDate = ''
    #print(url)
    page = requests.get(url+'/conceptArr?&type='+type+'&startDate='+str(startDate)+'&endDate='+str(endDate), params={"name":nameArr} )
    return page.json()

def getData(name,type,startDate='',endDate=''):
    if isinstance(name, int):
        return getDataByType(name,type)
    if not startDate:
        startDate = ''
    if not endDate:
        endDate = ''
    page = requests.get(url+'/code?name='+name+'&type='+type+'&startDate='+str(startDate)+'&endDate='+str(endDate), headers)
    return page.json()

#兼容大数据工具平台获得后台数据
def getDataByType(type,content):
    page = requests.get( url + '/bigDataCentre/getDataByType?content=' + content + '&type=' +str(type)  ,headers)
    df = pd.DataFrame(page.json())
    return df


def getDataByName(name,type,startDate='',endDate=''):
    page = requests.get(url+'/code?name='+name+'&type='+type+'&startDate='+str(startDate)+'&endDate='+str(endDate), headers)
    return page.json()


#获得财务报表的数据
def getAnnalReportData(industry,yearArr,companyList):
    #industry,yearArr,companyList
    page = requests.get(url+'/getAnnalReportAuditKeyData?industry='+industry, params={"yearArr":yearArr,"companyList":companyList})
    return page.json()



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from setuptools import setup, find_packages

setup(
    name = "onez",
    version = "0.0.33",



    keywords = ("pip", "testpypi"),
    description = "test pip module",
    long_description = "test how to define pip module and upload to pypi",
    license = "MIT",

    url = "http://127.0.0.1:5000/",
    #url = "https://99onez.com",          # your module home page, such as
    author = "99onez",                         # your name
    author_email = "99onez@qq.com",    # your email

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = []
)

'''

cd..
python setup.py sdist      
python setup.py bdist_egg
cd dist
pip install onez-0.0.33.tar.gz





'''


import plotly.graph_objects as go
from plotly.subplots import make_subplots

def dfpolt(title,df):
    # Create figure with secondary y-axis
    fig = make_subplots(specs=[[{"secondary_y": True}]])

    columns = df.columns
    # Add traces
    fig.add_trace(
        go.Bar(x=df.index, y=df.iloc[:,0], name=columns[0],
               text=df.iloc[:,0],
               textposition='outside',
               textfont=dict(
                   size=13,
                   color='#1f77b4')
               ),
        secondary_y=False,
    )

    fig.add_trace(
        go.Scatter(x=df.index, y=df.iloc[:,1], name=columns[1]),
        secondary_y=True,
    )

    # Add figure title
    fig.update_layout(
        title_text=title
    )

    # Set x-axis title
    fig.update_xaxes(title_text="", tickformat='%Y-%m')
    fig.update_traces(texttemplate='%{text:.2f}元')
    # Set y-axes titles
    fig.update_yaxes(title_text="<b>"+columns[0]+"</b>  ", secondary_y=False)
    fig.update_yaxes(title_text="<b>"+columns[1]+"</b>  ", secondary_y=True)

    fig.update_layout(
        autosize=False,
        width=1000,
        height=600,
        margin=dict(
            l=20,
            r=20,
            b=40,
            t=40,
            pad=4
        ),
        paper_bgcolor="LightSteelBlue",
    )
    return fig